var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};
import { immutableMergeCore } from '@uifabricshared/immutable-merge';
import { mergeAndFlattenStyles } from './Styles';
/**
 * helper function to switch to a collection merge pattern when _overrides are encountered
 */
function _mergeCollection(_options) {
    var objs = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        objs[_i - 1] = arguments[_i];
    }
    // eslint-disable-next-line @typescript-eslint/no-use-before-define
    return mergeSettingsCollection.apply(void 0, objs);
}
function _mergeStyles(_options) {
    var objs = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        objs[_i - 1] = arguments[_i];
    }
    return mergeAndFlattenStyles.apply(void 0, __spreadArrays([undefined, undefined], objs));
}
function _mergeClassName(_options) {
    var names = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        names[_i - 1] = arguments[_i];
    }
    return names.filter(function (v) { return v && typeof v === 'string'; }).join(' ');
}
/**
 * styles should be flattened and merged
 * tokens should be merged one level
 * overrides should be handled as a collection
 */
var _recurseOptions = {
    style: _mergeStyles,
    tokens: true,
    className: _mergeClassName,
    _overrides: _mergeCollection
};
/**
 * for a single settings block, recurse one level deep to include the various slot props
 */
var _mergeSettingsOptions = {
    depth: 1,
    recurse: _recurseOptions
};
/**
 * for a collection of settings, recurse two levels
 */
var _mergeCollectionOptions = {
    depth: 2,
    recurse: _recurseOptions
};
var _mergePropsOptions = {
    recurse: {
        style: _mergeStyles,
        tokens: true,
        className: _mergeClassName
    }
};
/**
 * Merge settings together.  This routine should work for IComponentSettings types or ISlotProps
 * @param settings - settings to merge together
 */
export function mergeSettings() {
    var settings = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        settings[_i] = arguments[_i];
    }
    return immutableMergeCore.apply(void 0, __spreadArrays([_mergeSettingsOptions], settings));
}
/**
 * Merge props together, flattening and merging styles as appropriate
 * @param props - props to merge together
 */
export function mergeProps() {
    var props = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        props[_i] = arguments[_i];
    }
    return immutableMergeCore.apply(void 0, __spreadArrays([_mergePropsOptions], props));
}
/**
 * Merge settings together and run finalization as part of the process
 *
 * @param theme - theme to use for value lookups
 * @param finalizers - finalizers to use for style processing
 * @param settings - settings to merge, can be only a single entry
 */
export function mergeAndFinalizeSettings(finalizer) {
    var settings = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        settings[_i - 1] = arguments[_i];
    }
    var mergeOptions = {
        depth: 1,
        processSingles: true,
        recurse: __assign(__assign({}, _recurseOptions), { style: function (_options) {
                var objs = [];
                for (var _i = 1; _i < arguments.length; _i++) {
                    objs[_i - 1] = arguments[_i];
                }
                return mergeAndFlattenStyles.apply(void 0, __spreadArrays([finalizer], objs));
            } })
    };
    return immutableMergeCore.apply(void 0, __spreadArrays([mergeOptions], settings));
}
/**
 * Merge collections of settings together.  This can handle theme resolution or merging sets of overrides
 * @param collections - the settings collections to merge
 */
export function mergeSettingsCollection() {
    var collections = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        collections[_i] = arguments[_i];
    }
    return immutableMergeCore.apply(void 0, __spreadArrays([_mergeCollectionOptions], collections));
}
export function getActiveOverrides(target, lookup) {
    var hasOverride = typeof lookup === 'function' ? lookup : function (o) { return lookup[o]; };
    return (target && target._precedence && target._precedence.filter(function (o) { return hasOverride(o); })) || [];
}
/**
 * Apply overrides to `target`, producing a new settings object if any need to be applied.
 *
 * `overrideLookup` is an object where keys will be looked up in the order specified by the precedence array.
 * The values inside this structure can be any type but will cause the override to apply if they are truthy
 */
export function resolveSettingsOverrides(target, overrideLookup) {
    var result = target;
    var _overrides = target._overrides, _precedence = target._precedence;
    if (overrideLookup && _overrides && _precedence) {
        var overrides = getActiveOverrides(target, overrideLookup);
        for (var _i = 0, overrides_1 = overrides; _i < overrides_1.length; _i++) {
            var override = overrides_1[_i];
            result = mergeSettings(result, result._overrides[override]);
        }
    }
    return result;
}
/**
 * Turn a settings object into a slot props object.
 * @param target - settings block to strip the settings specific information from
 */
export function slotPropsFromSettings(target) {
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    var _overrides = target._overrides, _precedence = target._precedence, slotProps = __rest(target, ["_overrides", "_precedence"]);
    return slotProps;
}
//# sourceMappingURL=Settings.js.map