var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import { flattenStyle, mergeAndFlattenStyles } from './Styles';
var theme = {
    palette: {
        bodyBackground: '#ff0000',
        bodyText: '#000000'
    },
    typography: {
        families: {
            primary: 'Arial'
        },
        sizes: {
            medium: 14
        },
        weights: {
            medium: '500'
        }
    }
};
var styleFinalizer = function (target) {
    var newStyle = {};
    if (target.backgroundColor) {
        var newVal = theme.palette[target.backgroundColor];
        if (newVal) {
            newStyle.backgroundColor = newVal;
        }
    }
    if (target.color) {
        var newVal = theme.palette[target.color];
        if (newVal) {
            newStyle.color = newVal;
        }
    }
    if (target.fontFamily) {
        var newVal = theme.typography.families[target.fontFamily];
        if (newVal) {
            newStyle.fontFamily = newVal;
        }
    }
    return newStyle;
};
var s1 = [
    { backgroundColor: 'blue' },
    [{ color: 'red', borderWidth: 1 }, { fontFamily: 'segoe' }, [{ backgroundColor: 'bodyBackground' }]]
];
var s1flatten = {
    backgroundColor: 'bodyBackground',
    color: 'red',
    borderWidth: 1,
    fontFamily: 'segoe'
};
var s1flattenFinal = {
    backgroundColor: theme.palette.bodyBackground,
    color: 'red',
    borderWidth: 1,
    fontFamily: 'segoe'
};
var s2 = {
    borderWidth: 2,
    fontFamily: 'primary',
    color: 'bodyText'
};
var s2Final = {
    borderWidth: 2,
    fontFamily: theme.typography.families.primary,
    color: theme.palette.bodyText
};
var sMerged = {
    backgroundColor: 'bodyBackground',
    borderWidth: 2,
    fontFamily: 'primary',
    color: 'bodyText'
};
var sMergedFinal = __assign(__assign({}, s1flattenFinal), s2Final);
var sSelector = {
    borderWidth: 1,
    ':hover': {
        borderWidth: 2,
        fontFamily: 'primary'
    }
};
var sSelector2 = {
    backgroundColor: 'white',
    ':hover': {
        backgroundColor: 'black',
        borderWidth: 3
    }
};
var sArraySelector = [[sSelector]];
var sArraySelector2 = [sSelector2];
var sMergedSelectors = {
    borderWidth: 1,
    backgroundColor: 'white',
    ':hover': {
        borderWidth: 3,
        fontFamily: 'primary',
        backgroundColor: 'black'
    }
};
describe('Style flatten and merge tests', function () {
    test('flatten recursive arrays', function () {
        var flattened = flattenStyle(s1);
        expect(flattened).toEqual(s1flatten);
        expect(flattened).not.toBe(s1);
    });
    test('flatten flat style returns style', function () {
        var flattened = flattenStyle(s2);
        expect(flattened).toBe(s2);
    });
    test('merge also flattens', function () {
        var merged = mergeAndFlattenStyles(undefined, undefined, s1, s2);
        expect(merged).toEqual(sMerged);
    });
    test('merge with sub objects', function () {
        var merged = mergeAndFlattenStyles(undefined, undefined, sSelector, sSelector2);
        expect(merged).toEqual(sMergedSelectors);
    });
    test('merge sub objects in arrays', function () {
        var merged = mergeAndFlattenStyles(undefined, undefined, sArraySelector, sArraySelector2);
        expect(merged).toEqual(sMergedSelectors);
    });
    test('finalize single style', function () {
        var final = mergeAndFlattenStyles(styleFinalizer, s1);
        expect(final).toEqual(s1flattenFinal);
        var final2 = mergeAndFlattenStyles(styleFinalizer, s2);
        expect(final2).toEqual(s2Final);
    });
    test('merge and finalize style', function () {
        var mergedAndFinal = mergeAndFlattenStyles(styleFinalizer, s1, s2);
        expect(mergedAndFinal).toEqual(sMergedFinal);
    });
});
//# sourceMappingURL=Styles.test.js.map